@@ -25,9 +25,7 @@ class AcceptOrganizationInvitationRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param Id: Invitation ID
-        :type Id: int
-        """
+        :param Id: Invitation ID\n        :type Id: int\n        """
         self.Id = None
 
 
@@ -49,9 +47,7 @@ class AcceptOrganizationInvitationResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
-        :type RequestId: str
-        """
+        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.\n        :type RequestId: str\n        """
         self.RequestId = None
 
 
@@ -66,11 +62,7 @@ class AddOrganizationNodeRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param ParentNodeId: Parent organizational unit ID
-        :type ParentNodeId: int
-        :param Name: Organizational unit name
-        :type Name: str
-        """
+        :param ParentNodeId: Parent organizational unit ID\n        :type ParentNodeId: int\n        :param Name: Organizational unit name\n        :type Name: str\n        """
         self.ParentNodeId = None
         self.Name = None
 
@@ -94,11 +86,7 @@ class AddOrganizationNodeResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param NodeId: Organizational unit ID
-        :type NodeId: int
-        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
-        :type RequestId: str
-        """
+        :param NodeId: Organizational unit ID\n        :type NodeId: int\n        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.\n        :type RequestId: str\n        """
         self.NodeId = None
         self.RequestId = None
 
@@ -115,9 +103,7 @@ class CancelOrganizationInvitationRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param Id: Invitation ID
-        :type Id: int
-        """
+        :param Id: Invitation ID\n        :type Id: int\n        """
         self.Id = None
 
 
@@ -139,9 +125,7 @@ class CancelOrganizationInvitationResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
-        :type RequestId: str
-        """
+        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.\n        :type RequestId: str\n        """
         self.RequestId = None
 
 
@@ -156,9 +140,7 @@ class CreateOrganizationRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param OrgType: Organization type; currently its value is fixed as `1`
-        :type OrgType: int
-        """
+        :param OrgType: Organization type; currently its value is fixed as `1`\n        :type OrgType: int\n        """
         self.OrgType = None
 
 
@@ -180,17 +162,7 @@ class CreateOrganizationResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param OrgId: Organization ID
-        :type OrgId: int
-        :param Nickname: Creator's name
-        :type Nickname: str
-        :param Mail: Creator's email address
-        :type Mail: str
-        :param OrgType: Organization type
-        :type OrgType: int
-        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
-        :type RequestId: str
-        """
+        :param OrgId: Organization ID\n        :type OrgId: int\n        :param Nickname: Creator's name\n        :type Nickname: str\n        :param Mail: Creator's email address\n        :type Mail: str\n        :param OrgType: Organization type\n        :type OrgType: int\n        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.\n        :type RequestId: str\n        """
         self.OrgId = None
         self.Nickname = None
         self.Mail = None
@@ -213,11 +185,7 @@ class DeleteOrganizationMemberFromNodeRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param MemberUin: UIN of the member to be deleted
-        :type MemberUin: int
-        :param NodeId: Organizational unit ID
-        :type NodeId: int
-        """
+        :param MemberUin: UIN of the member to be deleted\n        :type MemberUin: int\n        :param NodeId: Organizational unit ID\n        :type NodeId: int\n        """
         self.MemberUin = None
         self.NodeId = None
 
@@ -241,9 +209,7 @@ class DeleteOrganizationMemberFromNodeResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
-        :type RequestId: str
-        """
+        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.\n        :type RequestId: str\n        """
         self.RequestId = None
 
 
@@ -258,9 +224,7 @@ class DeleteOrganizationMembersRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param Uins: List of UINs of members to be deleted
-        :type Uins: list of int non-negative
-        """
+        :param Uins: List of UINs of members to be deleted\n        :type Uins: list of int non-negative\n        """
         self.Uins = None
 
 
@@ -282,9 +246,7 @@ class DeleteOrganizationMembersResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
-        :type RequestId: str
-        """
+        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.\n        :type RequestId: str\n        """
         self.RequestId = None
 
 
@@ -299,9 +261,7 @@ class DeleteOrganizationNodesRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param NodeIds: Organizational unit ID list
-        :type NodeIds: list of int non-negative
-        """
+        :param NodeIds: Organizational unit ID list\n        :type NodeIds: list of int non-negative\n        """
         self.NodeIds = None
 
 
@@ -323,9 +283,7 @@ class DeleteOrganizationNodesResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
-        :type RequestId: str
-        """
+        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.\n        :type RequestId: str\n        """
         self.RequestId = None
 
 
@@ -346,9 +304,7 @@ class DeleteOrganizationResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
-        :type RequestId: str
-        """
+        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.\n        :type RequestId: str\n        """
         self.RequestId = None
 
 
@@ -363,9 +319,7 @@ class DenyOrganizationInvitationRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param Id: Invitation ID
-        :type Id: int
-        """
+        :param Id: Invitation ID\n        :type Id: int\n        """
         self.Id = None
 
 
@@ -387,9 +341,7 @@ class DenyOrganizationInvitationResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
-        :type RequestId: str
-        """
+        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.\n        :type RequestId: str\n        """
         self.RequestId = None
 
 
@@ -404,9 +356,7 @@ class GetOrganizationMemberRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param MemberUin: Organization member UIN
-        :type MemberUin: int
-        """
+        :param MemberUin: Organization member UIN\n        :type MemberUin: int\n        """
         self.MemberUin = None
 
 
@@ -428,23 +378,7 @@ class GetOrganizationMemberResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param Uin: Organization member UIN
-        :type Uin: int
-        :param Name: Organization member name
-        :type Name: str
-        :param Remark: Notes
-        :type Remark: str
-        :param JoinTime: Joining time 
-        :type JoinTime: str
-        :param NodeId: Organizational unit ID
-        :type NodeId: int
-        :param NodeName: Organizational unit name
-        :type NodeName: str
-        :param ParentNodeId: Parent organizational unit ID
-        :type ParentNodeId: int
-        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
-        :type RequestId: str
-        """
+        :param Uin: Organization member UIN\n        :type Uin: int\n        :param Name: Organization member name\n        :type Name: str\n        :param Remark: Notes\n        :type Remark: str\n        :param JoinTime: Joining time \n        :type JoinTime: str\n        :param NodeId: Organizational unit ID\n        :type NodeId: int\n        :param NodeName: Organizational unit name\n        :type NodeName: str\n        :param ParentNodeId: Parent organizational unit ID\n        :type ParentNodeId: int\n        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.\n        :type RequestId: str\n        """
         self.Uin = None
         self.Name = None
         self.Remark = None
@@ -479,21 +413,7 @@ class GetOrganizationResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param OrgId: Organization ID
-        :type OrgId: int
-        :param HostUin: Creator UIN
-        :type HostUin: int
-        :param Nickname: Creator's name
-        :type Nickname: str
-        :param Mail: Creator's email address
-        :type Mail: str
-        :param OrgType: Organization type
-        :type OrgType: int
-        :param IsEmpty: Whether the organization is empty or not 
-        :type IsEmpty: int
-        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
-        :type RequestId: str
-        """
+        :param OrgId: Organization ID\n        :type OrgId: int\n        :param HostUin: Creator UIN\n        :type HostUin: int\n        :param Nickname: Creator's name\n        :type Nickname: str\n        :param Mail: Creator's email address\n        :type Mail: str\n        :param OrgType: Organization type\n        :type OrgType: int\n        :param IsEmpty: Whether the organization is empty or not \n        :type IsEmpty: int\n        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.\n        :type RequestId: str\n        """
         self.OrgId = None
         self.HostUin = None
         self.Nickname = None
@@ -520,13 +440,7 @@ class ListOrganizationInvitationsRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param Invited: Whether to list the invitations you received or the invitations you sent. `1`: list the invitations you received; `0`: list the invitations you sent.
-        :type Invited: int
-        :param Offset: Offset
-        :type Offset: int
-        :param Limit: Limit
-        :type Limit: int
-        """
+        :param Invited: Whether to list the invitations you received or the invitations you sent. `1`: list the invitations you received; `0`: list the invitations you sent.\n        :type Invited: int\n        :param Offset: Offset\n        :type Offset: int\n        :param Limit: Limit\n        :type Limit: int\n        """
         self.Invited = None
         self.Offset = None
         self.Limit = None
@@ -552,13 +466,7 @@ class ListOrganizationInvitationsResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param Invitations: List of invitations
-        :type Invitations: list of OrgInvitation
-        :param TotalCount: Total number of results
-        :type TotalCount: int
-        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
-        :type RequestId: str
-        """
+        :param Invitations: List of invitations\n        :type Invitations: list of OrgInvitation\n        :param TotalCount: Total number of results\n        :type TotalCount: int\n        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.\n        :type RequestId: str\n        """
         self.Invitations = None
         self.TotalCount = None
         self.RequestId = None
@@ -582,11 +490,7 @@ class ListOrganizationMembersRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param Offset: Offset
-        :type Offset: int
-        :param Limit: Limit
-        :type Limit: int
-        """
+        :param Offset: Offset\n        :type Offset: int\n        :param Limit: Limit\n        :type Limit: int\n        """
         self.Offset = None
         self.Limit = None
 
@@ -610,13 +514,7 @@ class ListOrganizationMembersResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param Members: Member list
-        :type Members: list of OrgMember
-        :param TotalCount: Total number of results
-        :type TotalCount: int
-        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
-        :type RequestId: str
-        """
+        :param Members: Member list\n        :type Members: list of OrgMember\n        :param TotalCount: Total number of results\n        :type TotalCount: int\n        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.\n        :type RequestId: str\n        """
         self.Members = None
         self.TotalCount = None
         self.RequestId = None
@@ -640,13 +538,7 @@ class ListOrganizationNodeMembersRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param NodeId: Organizational unit ID
-        :type NodeId: int
-        :param Offset: Offset
-        :type Offset: int
-        :param Limit: Limit
-        :type Limit: int
-        """
+        :param NodeId: Organizational unit ID\n        :type NodeId: int\n        :param Offset: Offset\n        :type Offset: int\n        :param Limit: Limit\n        :type Limit: int\n        """
         self.NodeId = None
         self.Offset = None
         self.Limit = None
@@ -672,13 +564,7 @@ class ListOrganizationNodeMembersResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param TotalCount: Total number of results
-        :type TotalCount: int
-        :param Members: Member list
-        :type Members: list of OrgMember
-        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
-        :type RequestId: str
-        """
+        :param TotalCount: Total number of results\n        :type TotalCount: int\n        :param Members: Member list\n        :type Members: list of OrgMember\n        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.\n        :type RequestId: str\n        """
         self.TotalCount = None
         self.Members = None
         self.RequestId = None
@@ -708,11 +594,7 @@ class ListOrganizationNodesResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param Nodes: Organizational unit list
-        :type Nodes: list of OrgNode
-        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
-        :type RequestId: str
-        """
+        :param Nodes: Organizational unit list\n        :type Nodes: list of OrgNode\n        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.\n        :type RequestId: str\n        """
         self.Nodes = None
         self.RequestId = None
 
@@ -734,11 +616,7 @@ class MoveOrganizationMembersToNodeRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param NodeId: Organizational unit ID
-        :type NodeId: int
-        :param Uins: Member UIN list
-        :type Uins: list of int non-negative
-        """
+        :param NodeId: Organizational unit ID\n        :type NodeId: int\n        :param Uins: Member UIN list\n        :type Uins: list of int non-negative\n        """
         self.NodeId = None
         self.Uins = None
 
@@ -762,9 +640,7 @@ class MoveOrganizationMembersToNodeResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
-        :type RequestId: str
-        """
+        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.\n        :type RequestId: str\n        """
         self.RequestId = None
 
 
@@ -779,29 +655,7 @@ class OrgInvitation(AbstractModel):
 
     def __init__(self):
         """
-        :param Id: Invitation ID
-        :type Id: int
-        :param Uin: UIN of the invitee
-        :type Uin: int
-        :param HostUin: Creator UIN
-        :type HostUin: int
-        :param HostName: Creator's name
-        :type HostName: str
-        :param HostMail: Creator's email address
-        :type HostMail: str
-        :param Status: Invitation status. `-1`: expired; `0`: normal; `1`: accepted; `2`: invalid; `3`: cancelled
-        :type Status: int
-        :param Name: Name
-        :type Name: str
-        :param Remark: Notes
-        :type Remark: str
-        :param OrgType: Organization type
-        :type OrgType: int
-        :param InviteTime: Time of invitation
-        :type InviteTime: str
-        :param ExpireTime: Expiration time
-        :type ExpireTime: str
-        """
+        :param Id: Invitation ID\n        :type Id: int\n        :param Uin: UIN of the invitee\n        :type Uin: int\n        :param HostUin: Creator UIN\n        :type HostUin: int\n        :param HostName: Creator's name\n        :type HostName: str\n        :param HostMail: Creator's email address\n        :type HostMail: str\n        :param Status: Invitation status. `-1`: expired; `0`: normal; `1`: accepted; `2`: invalid; `3`: cancelled\n        :type Status: int\n        :param Name: Name\n        :type Name: str\n        :param Remark: Notes\n        :type Remark: str\n        :param OrgType: Organization type\n        :type OrgType: int\n        :param InviteTime: Time of invitation\n        :type InviteTime: str\n        :param ExpireTime: Expiration time\n        :type ExpireTime: str\n        """
         self.Id = None
         self.Uin = None
         self.HostUin = None
@@ -843,15 +697,7 @@ class OrgMember(AbstractModel):
 
     def __init__(self):
         """
-        :param Uin: UIN
-        :type Uin: int
-        :param Name: Name
-        :type Name: str
-        :param Remark: Notes
-        :type Remark: str
-        :param JoinTime: Joining time
-        :type JoinTime: str
-        """
+        :param Uin: UIN\n        :type Uin: int\n        :param Name: Name\n        :type Name: str\n        :param Remark: Notes\n        :type Remark: str\n        :param JoinTime: Joining time\n        :type JoinTime: str\n        """
         self.Uin = None
         self.Name = None
         self.Remark = None
@@ -879,15 +725,7 @@ class OrgNode(AbstractModel):
 
     def __init__(self):
         """
-        :param NodeId: Organizational unit ID
-        :type NodeId: int
-        :param Name: Name
-        :type Name: str
-        :param ParentNodeId: Parent organizational unit ID
-        :type ParentNodeId: int
-        :param MemberCount: Number of members
-        :type MemberCount: int
-        """
+        :param NodeId: Organizational unit ID\n        :type NodeId: int\n        :param Name: Name\n        :type Name: str\n        :param ParentNodeId: Parent organizational unit ID\n        :type ParentNodeId: int\n        :param MemberCount: Number of members\n        :type MemberCount: int\n        """
         self.NodeId = None
         self.Name = None
         self.ParentNodeId = None
@@ -915,9 +753,7 @@ class QuitOrganizationRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param OrgId: Organization ID
-        :type OrgId: int
-        """
+        :param OrgId: Organization ID\n        :type OrgId: int\n        """
         self.OrgId = None
 
 
@@ -939,9 +775,7 @@ class QuitOrganizationResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
-        :type RequestId: str
-        """
+        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.\n        :type RequestId: str\n        """
         self.RequestId = None
 
 
@@ -956,13 +790,7 @@ class SendOrganizationInvitationRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param InviteUin: UIN of the invitee
-        :type InviteUin: int
-        :param Name: Name
-        :type Name: str
-        :param Remark: Notes
-        :type Remark: str
-        """
+        :param InviteUin: UIN of the invitee\n        :type InviteUin: int\n        :param Name: Name\n        :type Name: str\n        :param Remark: Notes\n        :type Remark: str\n        """
         self.InviteUin = None
         self.Name = None
         self.Remark = None
@@ -988,9 +816,7 @@ class SendOrganizationInvitationResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
-        :type RequestId: str
-        """
+        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.\n        :type RequestId: str\n        """
         self.RequestId = None
 
 
@@ -1005,13 +831,7 @@ class UpdateOrganizationMemberRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param MemberUin: Member UIN
-        :type MemberUin: int
-        :param Name: Name
-        :type Name: str
-        :param Remark: Notes
-        :type Remark: str
-        """
+        :param MemberUin: Member UIN\n        :type MemberUin: int\n        :param Name: Name\n        :type Name: str\n        :param Remark: Notes\n        :type Remark: str\n        """
         self.MemberUin = None
         self.Name = None
         self.Remark = None
@@ -1037,9 +857,7 @@ class UpdateOrganizationMemberResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
-        :type RequestId: str
-        """
+        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.\n        :type RequestId: str\n        """
         self.RequestId = None
 
 
@@ -1054,13 +872,7 @@ class UpdateOrganizationNodeRequest(AbstractModel):
 
     def __init__(self):
         """
-        :param NodeId: Organizational unit ID
-        :type NodeId: int
-        :param Name: Name
-        :type Name: str
-        :param ParentNodeId: Parent organizational unit ID
-        :type ParentNodeId: int
-        """
+        :param NodeId: Organizational unit ID\n        :type NodeId: int\n        :param Name: Name\n        :type Name: str\n        :param ParentNodeId: Parent organizational unit ID\n        :type ParentNodeId: int\n        """
         self.NodeId = None
         self.Name = None
         self.ParentNodeId = None
@@ -1086,9 +898,7 @@ class UpdateOrganizationNodeResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.
-        :type RequestId: str
-        """
+        :param RequestId: The unique request ID, which is returned for each request. RequestId is required for locating a problem.\n        :type RequestId: str\n        """
         self.RequestId = None
 
 
